solink-config-template
A dead simple template engine for configuration files.
Functions
- replace
- This is a simple templating engine for replacing variables in a YAML file with environment variables and other custom variables.
- replace_
str - Same as
replace, but uses aHashMap<&str, T>.